/* Generated by Nim Compiler v1.6.6 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <io.h>
#include <stdio.h>
#include <fcntl.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
  #  define nimfr_(proc, file) \
      TFrame FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = 0; nimFrame(&FR_);

  #  define nimfrs_(proc, file, slots, length) \
      struct {TFrame* prev;NCSTRING procname;NI line;NCSTRING filename; NI len; VarSlot s[slots];} FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = length; nimFrame((TFrame*)&FR_);

  #  define nimln_(n, file) \
      FR_.line = n; FR_.filename = file;
  static N_INLINE(void, nimFrame)(TFrame* s);
N_LIB_PRIVATE N_NOINLINE(void, callDepthLimitReached__system_2999)(void);
static N_INLINE(void, popFrame)(void);
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
static N_INLINE(void, nimFrame)(TFrame* s) {
	{
		if (!(framePtr__system_2566 == ((TFrame*) NIM_NIL))) goto LA3_;
		(*s).calldepth = ((NI16) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		(*s).calldepth = (NI16)((*framePtr__system_2566).calldepth + ((NI16) 1));
	}
	LA1_: ;
	(*s).prev = framePtr__system_2566;
	framePtr__system_2566 = s;
	{
		if (!((*s).calldepth == ((NI16) 2000))) goto LA8_;
		callDepthLimitReached__system_2999();
	}
	LA8_: ;
}
static N_INLINE(void, popFrame)(void) {
	framePtr__system_2566 = (*framePtr__system_2566).prev;
}
N_LIB_PRIVATE N_NIMCALL(void, stdlib_ioInit000)(void) {
{
	int T1_;
	int T2_;
	int T3_;
	nimfr_("io", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/io.nim");
	nimln_(842, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/io.nim");
	T1_ = (int)0;
	T1_ = _fileno(stdin);
	_setmode(T1_, _O_BINARY);
	nimln_(843, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/io.nim");
	T2_ = (int)0;
	T2_ = _fileno(stdout);
	_setmode(T2_, _O_BINARY);
	nimln_(844, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/io.nim");
	T3_ = (int)0;
	T3_ = _fileno(stderr);
	_setmode(T3_, _O_BINARY);
	popFrame();
}
}

